# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/libs/08_dtyp.ipynb.

# %% auto 0
__all__ = ['NPArray', 'ndarray', 'Idx', 'Index', 'Series', 'DFrame', 'DataFrame', 'DataFrames', 'IndexLike', 'SeriesLike',
           'IterLike', 'GroupKey']

# %% ../nbs/libs/08_dtyp.ipynb 4
from typing import TypeAlias, List, Union, Iterable, List

# %% ../nbs/libs/08_dtyp.ipynb 5
from .atyp import  Boolish, Numbers

# %% ../nbs/libs/08_dtyp.ipynb 7
try:
    import numpy as np
    arr = np.ndarray
except ImportError:
    # Define a placeholder type if numpy is not installed
    arr = 'numpy.ndarray'

# %% ../nbs/libs/08_dtyp.ipynb 8
NPArray: TypeAlias = arr
ndarray: TypeAlias = arr

# %% ../nbs/libs/08_dtyp.ipynb 10
try:
    import pandas as pd
    index = pd.Index
    dframe = pd.DataFrame
    series = pd.Series
except ImportError:
    # Define a placeholder type if pandas is not installed
    index = 'pandas.Index'    
    dframe = 'pandas.DataFrame'
    series = 'pandas.Series'

# %% ../nbs/libs/08_dtyp.ipynb 11
Idx: TypeAlias = index
Index: TypeAlias = index

Series: TypeAlias = series

DFrame: TypeAlias = dframe
DataFrame: TypeAlias = dframe

DataFrames: TypeAlias = List[DataFrame]

# %% ../nbs/libs/08_dtyp.ipynb 13
IndexLike: TypeAlias = Union[Numbers, List['Boolish'], 'Index']

SeriesLike: TypeAlias = Union[list, 'Series', 'ndarray', 'Tensor', 'IndexLike']

IterLike: TypeAlias = Union[Iterable, 'SeriesLike', 'IndexLike']

# %% ../nbs/libs/08_dtyp.ipynb 14
GroupKey: TypeAlias = Union[str, int, float, tuple] # key for pandas groupby



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/02_qtyp.ipynb.

# %% auto 0
__all__ = ['AnyQ', 'IntQ', 'SetQ', 'StrQ', 'ObjQ', 'BoolQ', 'DictQ', 'CallQ', 'TypeQ', 'ListQ', 'IterQ', 'FloatQ', 'TupleQ',
           'NumberQ', 'ComplexQ', 'StrLikeQ', 'ClsAnyQ', 'ClsIntQ', 'ClsSetQ', 'ClsStrQ', 'ClsObjQ', 'ClsBoolQ',
           'ClsCallQ', 'ClsTypeQ', 'ClsListQ', 'ClsIterQ', 'ClsFloatQ', 'ClsNumberQ', 'ClsComplexQ']

# %% ../nbs/02_qtyp.ipynb 4
from typing import (
    Type, TypeAlias, 
    ClassVar, Literal,
    Any, Optional, Callable, 
    List, Iterable, 
    Set, Tuple, Union, 
)

from numbers import Number

# %% ../nbs/02_qtyp.ipynb 5
from .atyp import Boolish, Numeric, StrLike

# %% ../nbs/02_qtyp.ipynb 7
AnyQ: TypeAlias = Optional[Any]
IntQ: TypeAlias = Optional[int]
SetQ: TypeAlias = Optional[set]
StrQ: TypeAlias = Optional[str]
ObjQ: TypeAlias = Optional[object]

BoolQ: TypeAlias = Optional[Boolish]
DictQ: TypeAlias = Optional[dict]
CallQ: TypeAlias = Optional[Callable]
TypeQ: TypeAlias = Optional[Type]
ListQ: TypeAlias = Optional[list]
IterQ: TypeAlias = Optional[Iterable]
FloatQ: TypeAlias = Optional[float]
TupleQ: TypeAlias = Optional[tuple]
NumberQ: TypeAlias = Optional[Numeric]
ComplexQ: TypeAlias = Optional[complex]

StrLikeQ: TypeAlias = Optional[StrLike]

# %% ../nbs/02_qtyp.ipynb 9
ClsAnyQ = ClassVar[AnyQ]
ClsIntQ = ClassVar[IntQ]
ClsSetQ = ClassVar[SetQ]
ClsStrQ = ClassVar[StrQ]
ClsObjQ = ClassVar[ObjQ]
ClsBoolQ = ClassVar[BoolQ]
ClsCallQ = ClassVar[CallQ]
ClsTypeQ = ClassVar[TypeQ]
ClsListQ = ClassVar[ListQ]
ClsIterQ = ClassVar[IterQ]
ClsFloatQ = ClassVar[FloatQ]
ClsNumberQ = ClassVar[NumberQ]
ClsComplexQ = ClassVar[ComplexQ]

StrLikeQ: TypeAlias = Optional[StrLike]



__version__ = "0.0.6"
from .atyp import *
from .ctyp import *
from .qtyp import *
from .ztyp import *

from .rtyp import *
from .ptyp import *
from .dtyp import *
from .btyp import *
from .mtyp import *



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/libs/09_btyp.ipynb.

# %% auto 0
__all__ = ['Adata', 'Adatas', 'AnnData', 'AnnDatas']

# %% ../nbs/libs/09_btyp.ipynb 4
from typing import TypeAlias, List

# %% ../nbs/libs/09_btyp.ipynb 6
try:
    import anndata as ad
    adata  = ad.AnnData
    adatas = List[adata]
except ImportError:
    # Define a placeholder type if anndata is not installed
    adata = 'anndata.AnnData'
    adatas = List[adata]

# %% ../nbs/libs/09_btyp.ipynb 7
Adata: TypeAlias = adata
Adatas: TypeAlias = adatas

AnnData: TypeAlias = adata
AnnDatas: TypeAlias = adatas



# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/atyp',
                'doc_host': 'https://dsm-72.github.io',
                'git_url': 'https://github.com/dsm-72/atyp',
                'lib_path': 'atyp'},
  'syms': { 'atyp.atyp': {},
            'atyp.btyp': {},
            'atyp.ctyp': {},
            'atyp.dtyp': {},
            'atyp.mtyp': {},
            'atyp.ptyp': {},
            'atyp.qtyp': {},
            'atyp.rtyp': {},
            'atyp.ztyp': {}}}



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/libs/06_rtyp.ipynb.

# %% auto 0
__all__ = ['RTree', 'RText', 'RCons', 'RProg', 'TApp']

# %% ../nbs/libs/06_rtyp.ipynb 4
from typing import TypeAlias

# %% ../nbs/libs/06_rtyp.ipynb 6
try:
    from rich.tree import Tree
    from rich.text import Text
    from rich.console import Console
    from rich.progress import Progress
    tree = Tree
    text = Text
    cons = Console
    prog = Progress
    
except ImportError:
    tree = 'rich.tree.Tree'
    text = 'rich.text.Text'
    cons = 'rich.console.Console'
    prog = 'rich.progress.Progress'

# %% ../nbs/libs/06_rtyp.ipynb 7
RTree: TypeAlias = tree
RText: TypeAlias = text
RCons: TypeAlias = cons
RProg: TypeAlias = prog

# %% ../nbs/libs/06_rtyp.ipynb 9
try:
    from typer import Typer
    tapp = Typer    
except ImportError:
    tapp = 'typer.Typer'

# %% ../nbs/libs/06_rtyp.ipynb 10
TApp: TypeAlias = tapp



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/01_ctyp.ipynb.

# %% auto 0
__all__ = ['ClsInt', 'ClsSet', 'ClsStr', 'ClsObj', 'ClsBool', 'ClsBoolish', 'ClsCall', 'ClsType', 'ClsList', 'ClsFloat',
           'ClsNumber', 'ClsComplex']

# %% ../nbs/01_ctyp.ipynb 4
from typing import (
    Type, TypeAlias, ClassVar, Callable
)

# %% ../nbs/01_ctyp.ipynb 5
from .atyp import Boolish, Numeric, StrLike

# %% ../nbs/01_ctyp.ipynb 7
ClsInt = ClassVar[int]
ClsSet = ClassVar[set]
ClsStr = ClassVar[str]
ClsObj = ClassVar[object]

ClsBool = ClassVar[bool]
ClsBoolish = ClassVar[Boolish]
ClsCall = ClassVar[Callable]

ClsType = ClassVar[type]
ClsList = ClassVar[list]

ClsFloat = ClassVar[float]
ClsNumber = ClassVar[Numeric]
ClsComplex = ClassVar[complex]



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/libs/10_mtyp.ipynb.

# %% auto 0
__all__ = ['Tensor', 'Device']

# %% ../nbs/libs/10_mtyp.ipynb 4
from typing import TypeAlias

# %% ../nbs/libs/10_mtyp.ipynb 6
try:
    import torch
    tensor = torch.Tensor
    device = torch.device
except ImportError:
    # Define a placeholder type if torch is not installed
    tensor = 'torch.Tensor'
    device = 'torch.device'

# %% ../nbs/libs/10_mtyp.ipynb 7
Tensor: TypeAlias = tensor
Device: TypeAlias = device



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/00_atyp.ipynb.

# %% auto 0
__all__ = ['Boolic', 'Boolish', 'Bools', 'Numeric', 'Numbers', 'StrLike', 'Strs', 'StrSet', 'PathType', 'PathLike', 'DirPath',
           'DirNames', 'FileNames', 'WalkParts', 'Intum', 'Strum', 'ByteLike', 'Literals', 'TypingLike', 'GuardLike',
           'Module', 'Loader', 'ModuleSpec', 'Sig', 'Param']

# %% ../nbs/00_atyp.ipynb 4
from typing import (
    TypeAlias, Literal, Union, List, Set,
    Iterable, Tuple
)

# %% ../nbs/00_atyp.ipynb 7
try:
    from numpy import bool_ as npbool
except ImportError:
    npbool = bool

# %% ../nbs/00_atyp.ipynb 8
Boolic: TypeAlias = Union[bool, npbool]
Boolish: TypeAlias = Union[bool, Boolic, Literal[0], Literal[1]]
Bools: TypeAlias = List[Boolish]

# %% ../nbs/00_atyp.ipynb 10
from numbers import Number

# %% ../nbs/00_atyp.ipynb 11
Numeric: TypeAlias = Union[int, float, complex, Number]
Numbers: TypeAlias = List[Numeric]

# %% ../nbs/00_atyp.ipynb 13
StrLike: TypeAlias = Union[str, 'strfix', 'fuzstr', 'nymstr', 'synset']
Strs: TypeAlias = List[StrLike]
StrSet: TypeAlias = Set[StrLike]

# %% ../nbs/00_atyp.ipynb 15
import pathlib

# %% ../nbs/00_atyp.ipynb 16
PathType: TypeAlias = Union[pathlib.Path, pathlib.PosixPath]

PathLike: TypeAlias = Union[str, PathType]

# %% ../nbs/00_atyp.ipynb 17
DirPath: TypeAlias = str
DirNames: TypeAlias =  List[str]
FileNames: TypeAlias =  List[str]
WalkParts: TypeAlias = Iterable[Tuple[DirPath, DirNames, FileNames]]

# %% ../nbs/00_atyp.ipynb 19
from enum import IntEnum, StrEnum

# %% ../nbs/00_atyp.ipynb 20
Intum: TypeAlias = Union[IntEnum, 'LitIntEnum', 'Intum']
Strum: TypeAlias = Union[StrEnum, 'LitStrEnum', 'Strum', 'LiteralEnum']

# %% ../nbs/00_atyp.ipynb 22
ByteLike: TypeAlias = Union[bytes, 'BytesUnit', 'Bytes']

# %% ../nbs/00_atyp.ipynb 24
from typing import TypeVar, TypeGuard

# %% ../nbs/00_atyp.ipynb 25
Literals = TypeVar('Literals')
TypingLike: TypeAlias = Union['TTyp', 'TType', 'TypingUnit', 'Typing']
GuardLike: TypeAlias = Union['TTypGuard', 'TTypeGuard']

# %% ../nbs/00_atyp.ipynb 27
import types

# %% ../nbs/00_atyp.ipynb 28
Module: TypeAlias = types.ModuleType

# %% ../nbs/00_atyp.ipynb 30
import importlib
from importlib.abc import Loader

# %% ../nbs/00_atyp.ipynb 31
Loader: TypeAlias = Loader

ModuleSpec: TypeAlias = importlib.machinery.ModuleSpec

# %% ../nbs/00_atyp.ipynb 33
import inspect

# %% ../nbs/00_atyp.ipynb 34
Sig: TypeAlias = inspect.Signature
Param: TypeAlias = inspect.Parameter



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/libs/07_ptyp.ipynb.

# %% auto 0
__all__ = ['Axes', 'ColorMap', 'CBarPos']

# %% ../nbs/libs/07_ptyp.ipynb 4
from typing import TypeAlias, Tuple

# %% ../nbs/libs/07_ptyp.ipynb 6
try:
    import matplotlib as mpl
    from matplotlib.axes._axes import Axes

    cmap = mpl.colors.Colormap
    axes = Axes

except ImportError:
    cmap = 'matplotlib.colors.Colormap'
    axes = 'matplotlib.axes._axes.Axes'

# %% ../nbs/libs/07_ptyp.ipynb 7
Axes: TypeAlias = axes
ColorMap: TypeAlias = cmap

# CBarPos: tuple of (left, bottom, width, height)
CBarPos: TypeAlias = Tuple[float, float, float, float]



# AUTOGENERATED! DO NOT EDIT! File to edit: ../nbs/03_ztyp.ipynb.

# %% auto 0
__all__ = ['FlagFunc', 'FlagFuncQ']

# %% ../nbs/03_ztyp.ipynb 4
from typing import List, Union, TypeAlias, Callable, Optional, ParamSpec

# %% ../nbs/03_ztyp.ipynb 6
from .atyp import Boolish
from .qtyp import AnyQ

# %% ../nbs/03_ztyp.ipynb 7
FlagFunc: TypeAlias = Callable[[AnyQ], Boolish]

FlagFuncQ: TypeAlias = Optional[FlagFunc]
